@@ -8,7 +8,7 @@ use FFI::Platypus::Function;
 use FFI::Platypus::Type;
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '1.24'; # VERSION
+our $VERSION = '1.25'; # VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -575,7 +575,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 1.24
+version 1.25
 
 =head1 SYNOPSIS
 
@@ -596,6 +596,7 @@ version 1.24
 
 Platypus is a library for creating interfaces to machine code libraries
 written in languages like C, L<C++|FFI::Platypus::Lang::CPP>,
+L<Go|FFI::Platypus::Lang::Go>,
 L<Fortran|FFI::Platypus::Lang::Fortran>,
 L<Rust|FFI::Platypus::Lang::Rust>,
 L<Pascal|FFI::Platypus::Lang::Pascal>. Essentially anything that gets
@@ -649,6 +650,7 @@ least some understanding of C, the C pre-processor, and some C++ caveats
 (since on some platforms Perl is compiled and linked with a C++
 compiler). Platypus on the other hand could be used to call other
 compiled languages, like L<Fortran|FFI::Platypus::Lang::Fortran>,
+L<Go|FFI::Platypus::Lang::Go>,
 L<Rust|FFI::Platypus::Lang::Rust>,
 L<Pascal|FFI::Platypus::Lang::Pascal>, L<C++|FFI::Platypus::Lang::CPP>,
 or even L<assembly|FFI::Platypus::Lang::ASM>, allowing you to focus
@@ -2316,6 +2318,10 @@ language
 
 Documentation and tools for using Platypus with Fortran
 
+=item L<FFI::Platypus::Lang::Go>
+
+Documentation and tools for using Platypus with Go
+
 =item L<FFI::Platypus::Lang::Pascal>
 
 Documentation and tools for using Platypus with Free Pascal
